options nocenter validvarname=any;

*---Read in space-delimited ascii file;

data new_data;


infile 'Weighting.dat' lrecl=44 missover DSD DLM=' ' print;
input
  R0000100
  R0214700
  R0214800
  T0987300
  T0987800
  T0988200
  T0988300
  T0988400
  T0988800
  T0989000
;
array nvarlist _numeric_;


*---Recode missing values to SAS custom system missing. See SAS
      documentation for use of MISSING option in procedures, e.g. PROC FREQ;

do over nvarlist;
  if nvarlist = -1 then nvarlist = .R;  /* Refused */
  if nvarlist = -2 then nvarlist = .D;  /* Dont know */
  if nvarlist = -3 then nvarlist = .I;  /* Invalid missing */
  if nvarlist = -4 then nvarlist = .V;  /* Valid missing */
  if nvarlist = -5 then nvarlist = .N;  /* Non-interview */
end;

  label R0000100 = "ID# (1-12686) 79";
  label R0214700 = "RACL/ETHNIC COHORT /SCRNR 79";
  label R0214800 = "SEX OF R 79";
  label T0987300 = "SAMPLING WEIGHT 2006";
  label T0987800 = "TOTAL NET FAMILY INCOME 2006";
  label T0988200 = "EMP STATUS RECODE (COLLAPSED) 2006";
  label T0988300 = "REGION OF RESIDENCE 2006";
  label T0988400 = "MARITAL STATUS (COLLAPSED) 2006";
  label T0988800 = "HIGHEST GRADE COMPLTD (REV) 2006";
  label T0989000 = "AGE AT INTERVIEW DATE 2006";

/*---------------------------------------------------------------------*
 *  Crosswalk for Reference number & Question name                     *
 *---------------------------------------------------------------------*
 * Uncomment and edit this RENAME statement to rename variables
 * for ease of use.  You may need to use  name literal strings
 * e.g.  'variable-name'n   to create valid SAS variable names, or 
 * alter variables similarly named across years.
 * This command does not guarentee uniqueness

 * See SAS documentation for use of name literals and use of the
 * VALIDVARNAME=ANY option.     
 *---------------------------------------------------------------------*/
  /* *start* */

* RENAME
  R0000100 = 'CASEID_1979'n
  R0214700 = '*Created_1979'n
  R0214800 = '*Created_1979'n
  T0987300 = 'SAMPWEIGHT_2006'n
  T0987800 = 'TNFI_2006'n
  T0988200 = 'ESR-COL_2006'n
  T0988300 = 'REGION_2006'n
  T0988400 = 'MARSTAT-COL_2006'n
  T0988800 = 'HGCREV06_2006'n
  T0989000 = 'AGEATINT_2006'n
;
  /* *finish* */

run;

proc means data=new_data n mean min max;
run;


/*---------------------------------------------------------------------*
 *  FORMATTED TABULATIONS                                              *
 *---------------------------------------------------------------------*
 * You can uncomment and edit the PROC FORMAT and PROC FREQ statements 
 * provided below to obtain formatted tabulations. The tabulations 
 * should reflect codebook values.
 * 
 * Please edit the formats below reflect any renaming of the variables
 * you may have done in the first data step. 
 *---------------------------------------------------------------------*/

/*
proc format; 
value vx1f
  1='HISPANIC'
  2='BLACK'
  3='NON-BLACK, NON-HISPANIC'
;
value vx2f
  1='MALE'
  2='FEMALE'
;
value vx3f
  0='0'
  1-49999='1 TO 49999'
  50000-99999='50000 TO 99999'
  100000-149999='100000 TO 149999'
  150000-199999='150000 TO 199999'
  200000-249999='200000 TO 249999'
  250000-299999='250000 TO 299999'
  300000-399999='300000 TO 399999'
  400000-499999='400000 TO 499999'
  500000-599999='500000 TO 599999'
  600000-699999='600000 TO 699999'
  700000-799999='700000 TO 799999'
  800000-899999='800000 TO 899999'
  900000-999999='900000 TO 999999'
  1000000-1999999='1000000 TO 1999999'
  2000000-2999999='2000000 TO 2999999'
  3000000-3999999='3000000 TO 3999999'
  4000000-4999999='4000000 TO 4999999'
  5000000-5999999='5000000 TO 5999999'
  6000000-6999999='6000000 TO 6999999'
  7000000-7999999='7000000 TO 7999999'
  8000000-8999999='8000000 TO 8999999'
  9000000-9999999='9000000 TO 9999999'
  10000000-99999999999='10000000 TO 99999999999: 10000000+'
;
value vx4f
  0='0'
  1-999='1 TO 999'
  1000-1999='1000 TO 1999'
  2000-2999='2000 TO 2999'
  3000-3999='3000 TO 3999'
  4000-4999='4000 TO 4999'
  5000-5999='5000 TO 5999'
  6000-6999='6000 TO 6999'
  7000-7999='7000 TO 7999'
  8000-8999='8000 TO 8999'
  9000-9999='9000 TO 9999'
  10000-14999='10000 TO 14999'
  15000-19999='15000 TO 19999'
  20000-24999='20000 TO 24999'
  25000-49999='25000 TO 49999'
  50000-99999999='50000 TO 99999999: 50000+'
;
value vx5f
  1='1: EMPLOYED'
  2='2: UNEMPLOYED'
  3='3: OUT OF LABOR FORCE'
  4='4: IN ACTIVE FORCES'
;
value vx6f
  1='1: 1  NORTHEAST'
  2='2: 2  NORTH CENTRAL'
  3='3: 3  SOUTH'
  4='4: 4  WEST'
;
value vx7f
  1='1: 1  NEVER MARRIED'
  2='2: 2  MARRIED, SPOUSE PRESENT'
  3='3: 3  OTHER'
;
value vx8f
  0='NONE'
  93='PRE-KINDERGARTEN'
  94='KINDERGARTEN'
  1='1ST GRADE'
  2='2ND GRADE'
  3='3RD GRADE'
  4='4TH GRADE'
  5='5TH GRADE'
  6='6TH GRADE'
  7='7TH GRADE'
  8='8TH GRADE'
  9='9TH GRADE'
  10='10TH GRADE'
  11='11TH GRADE'
  12='12TH GRADE'
  13='1ST YEAR COLLEGE'
  14='2ND YEAR COLLEGE'
  15='3RD YEAR COLLEGE'
  16='4TH YEAR COLLEGE'
  17='5TH YEAR COLLEGE'
  18='6TH YEAR COLLEGE'
  19='7TH YEAR COLLEGE'
  20='8TH YEAR COLLEGE OR MORE'
  95='UNGRADED'
;
value vx9f
  40='40'
  41='41'
  42='42'
  43='43'
  44='44'
  45='45'
  46='46'
  47='47'
  48='48'
  49='49'
  50='50'
  51='51'
  52='52'
;
*/

/* 
 *--- Tabulations using reference number variables;
proc freq data=new_data;
tables _ALL_ /MISSING;
  format R0214700 vx1f.;
  format R0214800 vx2f.;
  format T0987300 vx3f.;
  format T0987800 vx4f.;
  format T0988200 vx5f.;
  format T0988300 vx6f.;
  format T0988400 vx7f.;
  format T0988800 vx8f.;
  format T0989000 vx9f.;
run;
*/

/*
*--- Tabulations using default named variables;
proc freq data=new_data;
tables _ALL_ /MISSING;
  format *Created vx1f.;
  format *Created vx2f.;
  format SAMPWEIGHT vx3f.;
  format TNFI vx4f.;
  format ESR-COL vx5f.;
  format REGION vx6f.;
  format MARSTAT-COL vx7f.;
  format HGCREV06 vx8f.;
  format AGEATINT vx9f.;
run;
*/

