options nocenter validvarname=any;

*---Read in space-delimited ascii file;

data new_data;


infile 'agemarj06.dat' lrecl=99 missover DSD DLM=' ' print;
input
  C0000100
  C0000200
  C0005300
  C0005400
  C0005700
  C0011201
  C0011203
  C0011205
  C0011207
  C0011209
  C0011211
  C0011213
  C0733300
  C0945000
  C1140400
  C1370500
  C1592600
  C1933400
  C2472600
  C2770600
  C3050500
  C3370800
  Y0364900
  Y0658900
  Y0954900
  Y1168700
  Y1407900
  Y1659300
  Y1932500
;
array nvarlist _numeric_;


*---Recode missing values to SAS custom system missing. See SAS
      documentation for use of MISSING option in procedures, e.g. PROC FREQ;

do over nvarlist;
  if nvarlist = -1 then nvarlist = .R;  /* Refused */
  if nvarlist = -2 then nvarlist = .D;  /* Dont know */
  if nvarlist = -3 then nvarlist = .I;  /* Invalid missing */
  if nvarlist = -7 then nvarlist = .M;  /* Missing */
end;

  label C0000100 = "ID CODE OF CHILD";
  label C0000200 = "ID CODE OF MOTHER OF CHILD";
  label C0005300 = "RACE OF CHILD (FROM MOTHERS SCREENER 79)";
  label C0005400 = "SEX OF CHILD";
  label C0005700 = "DATE OF BIRTH OF CHILD - YEAR";
  label C0011201 = "WAS CHILD INTERVWD AS YOUNG ADULT?";
  label C0011203 = "WAS CHILD INTERVIEWED AS YOUNG ADULT? 96";
  label C0011205 = "WAS CHILD INTERVWD AS YOUNG ADULT? 1998";
  label C0011207 = "WAS CHILD INTERVWD AS YOUNG ADULT? 2000";
  label C0011209 = "WAS CHILD INTERVWD AS YOUNG ADULT? 2002";
  label C0011211 = "WAS CHILD INTERVWD AS YOUNG ADULT? 2004";
  label C0011213 = "WAS CHILD INTERVWD AS YOUNG ADULT? 2006";
  label C0733300 = "RS AGE WHEN FIRST USED MARIJUANA";
  label C0945000 = "CHILD'S AGE WHEN HE 1ST USED MARIJUANA";
  label C1140400 = "CH'S AGE WHEN S/HE 1ST USED MARIJUANA-92";
  label C1370500 = "CH AGE WHEN S/HE 1ST USED MARIJUANA 94";
  label C1592600 = "CH AGE WHEN S/HE 1ST USED MARIJUANA 96";
  label C1933400 = "AGE WHEN CHILD 1ST USED MARIJUANA 1998";
  label C2472600 = "AGE WHEN CHILD 1ST USED MARIJUANA 2000";
  label C2770600 = "AGE WHEN CHILD 1ST USED MARIJUANA 2002";
  label C3050500 = "AGE WHEN CHILD 1ST USED MARIJUANA 2004";
  label C3370800 = "AGE WHEN CHILD 1ST USED MARIJUANA 2006";
  label Y0364900 = "AGE WHEN FIRST USED MARIJUANA         94";
  label Y0658900 = "AGE WHEN FIRST USED MARIJUANA         96";
  label Y0954900 = "AGE WHEN FIRST USED MARIJUANA 1998";
  label Y1168700 = "AGE WHEN FIRST USED MARIJUANA 2000";
  label Y1407900 = "AGE WHEN FIRST USED MARIJUANA 2002";
  label Y1659300 = "AGE WHEN FIRST USED MARIJUANA 2004";
  label Y1932500 = "AGE WHEN FIRST USED MARIJUANA 2006";

/*---------------------------------------------------------------------*
 *  Crosswalk for Reference number & Question name                     *
 *---------------------------------------------------------------------*
 * Uncomment and edit this RENAME statement to rename variables
 * for ease of use.  You may need to use  name literal strings
 * e.g.  'variable-name'n   to create valid SAS variable names, or 
 * alter variables similarly named across years.
 * This command does not guarentee uniqueness

 * See SAS documentation for use of name literals and use of the
 * VALIDVARNAME=ANY option.     
 *---------------------------------------------------------------------*/
  /* *start* */

* RENAME
  C0000100 = 'CPUBID_XRND'n
  C0000200 = 'MPUBID_XRND'n
  C0005300 = 'CRACE_XRND'n
  C0005400 = 'CSEX_XRND'n
  C0005700 = 'CYRB_XRND'n
  C0011201 = 'YAINTV1994_1994'n
  C0011203 = 'YAINTV1996_1996'n
  C0011205 = 'YAINTV1998_1998'n
  C0011207 = 'YAINTV2000_2000'n
  C0011209 = 'YAINTV2002_2002'n
  C0011211 = 'YAINTV2004_2004'n
  C0011213 = 'YAINTV2006_2006'n
  C0733300 = 'CS884252_1988'n
  C0945000 = 'CS906665_1990'n
  C1140400 = 'CS926865_1992'n
  C1370500 = 'CS942649_1994'n
  C1592600 = 'CS960945_1996'n
  C1933400 = 'CS98063_1998'n
  C2472600 = 'CSAS063_2000'n
  C2770600 = 'CSAS063_2002'n
  C3050500 = 'CSAS063_2004'n
  C3370800 = 'CSAS063_2006'n
  Y0364900 = 'YA940413_1994'n
  Y0658900 = 'YA960355_1996'n
  Y0954900 = 'YA98032_1998'n
  Y1168700 = 'YASR-25_2000'n
  Y1407900 = 'YASR-25_2002'n
  Y1659300 = 'YASR-25_2004'n
  Y1932500 = 'YASR-25_2006'n
;
  /* *finish* */

run;

proc means data=new_data n mean min max;
run;


/*---------------------------------------------------------------------*
 *  FORMATTED TABULATIONS                                              *
 *---------------------------------------------------------------------*
 * You can uncomment and edit the PROC FORMAT and PROC FREQ statements 
 * provided below to obtain formatted tabulations. The tabulations 
 * should reflect codebook values.
 * 
 * Please edit the formats below reflect any renaming of the variables
 * you may have done in the first data step. 
 *---------------------------------------------------------------------*/

/*
proc format; 
*/

/* 
 *--- Tabulations using reference number variables;
proc freq data=new_data;
tables _ALL_ /MISSING;
run;
*/

/*
*--- Tabulations using default named variables;
proc freq data=new_data;
tables _ALL_ /MISSING;
run;
*/

